==> haskell-reducers-3.12.1-33-i686.pkg.tar.xz: usr/share/haskell/register/haskell-reducers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: reducers
version: 3.12.1
id: reducers-3.12.1-Ht4a7jugA5A5jE9S7HTqYz
key: reducers-3.12.1-Ht4a7jugA5A5jE9S7HTqYz
license: BSD3
copyright: Copyright (C) 2008-2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/reducers/
synopsis: Semigroups, specialized containers and a general map/reduce framework
description:
    Semigroups, specialized containers and a general map/reduce framework
category: Data, Math, Numerical, Semigroups
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Generator Data.Generator.Combinators Data.Semigroup.Generator
    Data.Semigroup.Reducer Data.Semigroup.Reducer.With
    Data.Semigroup.Instances Data.Semigroup.Union Data.Semigroup.Apply
    Data.Semigroup.Applicative Data.Semigroup.Alt
    Data.Semigroup.Alternative Data.Semigroup.Monad
    Data.Semigroup.MonadPlus Data.Semigroup.Self
abi: 64f8a1d8896b2471d9eadb5280b91da0
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/reducers-3.12.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/reducers-3.12.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/reducers-3.12.1
hs-libraries: HSreducers-3.12.1-Ht4a7jugA5A5jE9S7HTqYz
depends:
    array-0.5.1.1 base-4.9.1.0 bytestring-0.10.8.1 containers-0.5.7.1
    fingertree-0.1.1.0-Aiaf912zjZGHvH3XyjxrYA
    hashable-1.2.6.1-2nPqxcHq7mUGgurrYaLtXr
    semigroupoids-5.2-I9hFsiKk7FC4Vp6kTTs0M3
    semigroups-0.18.3-5xL9BgkWQsCGwo6YahyMCM
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq transformers-0.5.2.0
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
haddock-interfaces: /usr/share/doc/haskell-reducers/html/reducers.haddock
haddock-html: /usr/share/doc/haskell-reducers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-reducers-3.12.1-34-i686.pkg.tar.xz: usr/share/haskell/register/haskell-reducers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: reducers
version: 3.12.1
id: reducers-3.12.1-oQwGPg4IdHSyMXJrkqbP
key: reducers-3.12.1-oQwGPg4IdHSyMXJrkqbP
license: BSD3
copyright: Copyright (C) 2008-2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/reducers/
synopsis: Semigroups, specialized containers and a general map/reduce framework
description:
    Semigroups, specialized containers and a general map/reduce framework
category: Data, Math, Numerical, Semigroups
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Generator Data.Generator.Combinators Data.Semigroup.Generator
    Data.Semigroup.Reducer Data.Semigroup.Reducer.With
    Data.Semigroup.Instances Data.Semigroup.Union Data.Semigroup.Apply
    Data.Semigroup.Applicative Data.Semigroup.Alt
    Data.Semigroup.Alternative Data.Semigroup.Monad
    Data.Semigroup.MonadPlus Data.Semigroup.Self
abi: 71de091d1562dc271d0d09acb4defce6
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/reducers-3.12.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/reducers-3.12.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/reducers-3.12.1
hs-libraries: HSreducers-3.12.1-oQwGPg4IdHSyMXJrkqbP
depends:
    array-0.5.1.1 base-4.9.1.0 bytestring-0.10.8.1 containers-0.5.7.1
    fingertree-0.1.1.0-Aiaf912zjZGHvH3XyjxrYA
    hashable-1.2.6.1-2nPqxcHq7mUGgurrYaLtXr
    semigroupoids-5.2.1-AZdsYazgWLZ9acFdqW12To
    semigroups-0.18.3-5xL9BgkWQsCGwo6YahyMCM
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq transformers-0.5.2.0
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
haddock-interfaces: /usr/share/doc/haskell-reducers/html/reducers.haddock
haddock-html: /usr/share/doc/haskell-reducers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
